# Python Package Documentation

```{include} ../README.md
:start-line: 0
:relative-docs: docs
:relative-images:
```

<!-- hidden toc trees for sidebar -->

```{toctree}
:maxdepth: 2
:caption: "Tutorials"
:hidden: true

tutorial/analysis
tutorial/plotting
```

```{toctree}
:maxdepth: 2
:caption: "Reference"
:hidden: true

reference/growthcurves
```

```{toctree}
:maxdepth: 2
:caption: "Technical notes"
:hidden: true

README
developing
```

## Indices and tables

- [Index](genindex)
- [Module Index](modindex)
- [Search](search)
